import json
import numpy as np

# Read out samples
with open('./chi-effective-fractions.json','r') as jf:
    samps = json.load(jf)['posterior']
fPos = np.array(samps['fPos'])
fNeg = np.array(samps['fNeg'])
fVan = np.array(samps['fVan'])

with open('./chi-effective-fractions-variableMin.json','r') as jf:
    samps = json.load(jf)['posterior']
fPos_varMin = np.array(samps['fPos'])
fNeg_varMin = np.array(samps['fNeg'])
fVan_varMin = np.array(samps['fVan'])

# Construct toy "dynamical" and "field" fractions
fDyn = 2.*fNeg/(fPos+fNeg)
fIso = (fPos-fNeg)/(fPos+fNeg)

with open('./gaussian-spin-fraction-macros.tex','w') as macrofile:

    # 1%, 5%, 10%, and 95% quantiles on fNeg, expressed as a *percentage*
    macrofile.write("% 01\% quantile on fNeg posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeExtremeLowerLimit}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fNeg,0.01)))
    macrofile.write("% 05\% quantile on fNeg posterior (percentage) \n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeLow}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fNeg,0.05)))
    macrofile.write("% 10\% quantile on fNeg posterior (percentage) \n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeLowerLimit}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fNeg,0.10)))
    macrofile.write("% 95\% quantile on fNeg posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeHigh}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fNeg,0.95)))

    macrofile.write("\n")

    # Median and uncertainty on fNeg, expressed as a *fraction*
    macrofile.write("% 50\% quantile on fNeg posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegative}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg,0.50)))
    macrofile.write("% Upper error on fNeg (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeErrorHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg,0.95)-np.quantile(fNeg,0.50)))
    macrofile.write("% Lower error on fNeg (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeErrorLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg,0.50)-np.quantile(fNeg,0.05)))

    macrofile.write("\n")

    # 90\% bounds on fPos, expressed as a *percentage*
    macrofile.write("% 05\% quantile on fPos posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveLow}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fPos,0.05)))
    macrofile.write("% 95\% quantile on fPos posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveHigh}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fPos,0.95)))

    macrofile.write("\n")

    # Median and uncertainty on fPos, expressed as a *fraction*
    macrofile.write("% 50\% quantile on fPos posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositive}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fPos,0.50)))
    macrofile.write("% Upper error on fPos (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveErrorHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fPos,0.95)-np.quantile(fPos,0.50)))
    macrofile.write("% Lower error on fPos (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveErrorLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fPos,0.50)-np.quantile(fPos,0.05)))

    macrofile.write("\n")

    # Bounds on fVan, expressed as a *percentage*
    macrofile.write("% 05\% quantile on fVan posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffVanishingLow}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fVan,0.05)))
    macrofile.write("% 90\% quantile on fVan posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffVanishingUpperLimit}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fVan,0.90)))
    macrofile.write("% 95\% quantile on fVan posterior (percentage)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffVanishingHigh}}{{\\ensuremath{{{0:.0f}}}}}\n".format(100*np.quantile(fVan,0.95)))

    macrofile.write("\n")

    # Bounds on fVan, expressed as a *fraction*
    macrofile.write("% 50\% quantile on fVan posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffVanishing}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fVan,0.50)))
    macrofile.write("% Upper error on fVan (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffVanishingErrorHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fVan,0.95)-np.quantile(fVan,0.50)))
    macrofile.write("% Lower error on fVan (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffVanishingErrorLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fVan,0.50)-np.quantile(fVan,0.05)))

    macrofile.write("\n")

    # Bounds on fDyn, expressed as a *fraction*
    macrofile.write("% 05\% quantile on fDyn posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffDynamicalLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fDyn,0.05)))
    macrofile.write("% 95\% quantile on fDyn posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffDynamicalHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fDyn,0.95)))

    macrofile.write("\n")

    # Bounds on fIso, expressed as a *fraction*
    macrofile.write("% 05\% quantile on fIso posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffIsolatedLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fIso,0.05)))
    macrofile.write("% 05\% quantile on fIso posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffIsolatedHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fIso,0.95)))

    macrofile.write("\n")

    ## Variable minimum truncation
    # Median and uncertainty on fNeg, expressed as a *fraction*
    macrofile.write("% 50\% quantile on fNeg posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg_varMin,0.50)))
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeLowerLimVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg_varMin,0.05)))
    macrofile.write("% Upper error on fNeg (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeErrorHighVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg_varMin,0.95)-np.quantile(fNeg_varMin,0.50)))
    macrofile.write("% Lower error on fNeg (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffNegativeErrorLowVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fNeg_varMin,0.50)-np.quantile(fNeg_varMin,0.05)))

    macrofile.write("\n")

    # Median and uncertainty on fPos, expressed as a *fraction*
    macrofile.write("% 50\% quantile on fPos posterior (fraction)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fPos_varMin,0.50)))
    macrofile.write("% Upper error on fPos (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveErrorHighVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fPos_varMin,0.95)-np.quantile(fPos_varMin,0.50)))
    macrofile.write("% Lower error on fPos (fraction, 90\% credible bounds)\n")
    macrofile.write("\\newcommand{{\\fractionChiEffPositiveErrorLowVarMin}}{{\\ensuremath{{{0:.2f}}}}}\n".format(np.quantile(fPos_varMin,0.50)-np.quantile(fPos_varMin,0.05)))

